@@ -1,19 +1,16 @@
-/* eslint-disable no-undef, no-unused-vars */
-
 import * as React from 'react';
 import { ShallowWrapper, shallow } from 'enzyme';
 import Spy = jasmine.Spy;
 import * as _ from 'lodash-es';
 
-import { DisableApplicationModal, DisableApplicationModalProps, DisableApplicationModalState } from '../../../public/components/modals/disable-application-modal';
+import { DisableApplicationModal, DisableApplicationModalProps } from '../../../public/components/modals/disable-application-modal';
 import { ModalTitle, ModalSubmitFooter } from '../../../public/components/factory/modal';
 import { testSubscription } from '../../../__mocks__/k8sResourcesMocks';
 import { SubscriptionKind } from '../../../public/components/operator-lifecycle-manager/index';
-import { ClusterServiceVersionModel, SubscriptionModel, CatalogSourceConfigModel } from '../../../public/models';
-import { apiVersionForModel } from '../../../public/module/k8s';
+import { ClusterServiceVersionModel, SubscriptionModel } from '../../../public/models';
 
 describe(DisableApplicationModal.name, () => {
-  let wrapper: ShallowWrapper<DisableApplicationModalProps, DisableApplicationModalState>;
+  let wrapper: ShallowWrapper<DisableApplicationModalProps>;
   let k8sKill: Spy;
   let k8sGet: Spy;
   let k8sPatch: Spy;
@@ -34,7 +31,7 @@ describe(DisableApplicationModal.name, () => {
     cancel = jasmine.createSpy('cancel');
     subscription = {..._.cloneDeep(testSubscription), status: {installedCSV: 'testapp.v1.0.0'}};
 
-    wrapper = shallow(<DisableApplicationModal subscription={subscription} k8sKill={k8sKill} k8sGet={k8sGet} k8sPatch={k8sPatch} close={close} cancel={cancel} />);
+    wrapper = shallow(<DisableApplicationModal subscription={subscription} k8sKill={k8sKill} k8sGet={k8sGet} k8sPatch={k8sPatch} close={close} cancel={cancel} />).dive();
   });
 
   it('renders a modal form', () => {
@@ -85,7 +82,7 @@ describe(DisableApplicationModal.name, () => {
   });
 
   it('does not call `props.k8sKill` to delete `ClusterServiceVersion` if `state.deleteCSV` is false', (done) => {
-    wrapper = wrapper.setState({deleteCSV: false});
+    wrapper.find('input').simulate('click');
     wrapper = wrapper.setProps({subscription: testSubscription});
 
     spyAndExpect(close)(null).then(() => {
@@ -97,8 +94,6 @@ describe(DisableApplicationModal.name, () => {
   });
 
   it('adds delete options with `propagationPolicy` if cascading delete checkbox is checked', (done) => {
-    wrapper = wrapper.setState({deleteCSV: true});
-
     spyAndExpect(close)(null).then(() => {
       expect(k8sKill.calls.argsFor(0)[3]).toEqual({kind: 'DeleteOptions', apiVersion: 'v1', propagationPolicy: 'Foreground'});
       expect(k8sKill.calls.argsFor(1)[3]).toEqual({kind: 'DeleteOptions', apiVersion: 'v1', propagationPolicy: 'Foreground'});
@@ -108,54 +103,6 @@ describe(DisableApplicationModal.name, () => {
     wrapper.find('form').simulate('submit', new Event('submit'));
   });
 
-  it('calls `props.k8sKill` to update `CatalogSourceConfig` if subscription contains appropriate labels', (done) => {
-    subscription.metadata.labels = {
-      'csc-owner-name': 'test-csc',
-      'csc-owner-namespace': 'default',
-    };
-    wrapper = wrapper.setProps({subscription});
-
-    const catalogSourceConfig = {
-      apiVersion: apiVersionForModel(CatalogSourceConfigModel),
-      kind: CatalogSourceConfigModel.kind,
-      spec: {packages: [subscription.spec.name].join(',')},
-    };
-    k8sGet.and.returnValue(Promise.resolve(catalogSourceConfig));
-
-    spyAndExpect(close)(null).then(() => {
-      expect(k8sGet.calls.count()).toEqual(1);
-      expect(k8sKill.calls.argsFor(2)[1]).toEqual(catalogSourceConfig);
-      done();
-    });
-
-    wrapper.find('form').simulate('submit', new Event('submit'));
-  });
-
-  it('calls `props.k8sKill` to delete `CatalogSourceConfig` if subscription contains appropriate labels and is the last entry in `spec.packages`', (done) => {
-    subscription.metadata.labels = {
-      'csc-owner-name': 'test-csc',
-      'csc-owner-namespace': 'default',
-    };
-    wrapper = wrapper.setProps({subscription});
-
-    const catalogSourceConfig = {
-      apiVersion: apiVersionForModel(CatalogSourceConfigModel),
-      kind: CatalogSourceConfigModel.kind,
-      spec: {packages: [subscription.spec.name, 'other-package'].join(',')},
-    };
-    k8sGet.and.returnValue(Promise.resolve(catalogSourceConfig));
-
-    spyAndExpect(close)(null).then(() => {
-      expect(k8sGet.calls.count()).toEqual(1);
-      expect(k8sKill.calls.count()).toEqual(2);
-      expect(k8sPatch.calls.argsFor(0)[1]).toEqual(catalogSourceConfig);
-      expect(k8sPatch.calls.argsFor(0)[2]).toEqual([{op: 'replace', path: '/spec/packages', value: 'other-package'}]);
-      done();
-    });
-
-    wrapper.find('form').simulate('submit', new Event('submit'));
-  });
-
   it('calls `props.close` after successful submit', (done) => {
     spyAndExpect(close)(null).then(() => {
       done();
