@@ -1,5 +1,3 @@
-/* eslint-disable no-undef, no-unused-vars */
-
 import { $$, by, browser, element, ExpectedConditions as until } from 'protractor';
 
 export const horizontalTabFor = (name: string) => element(by.cssContainingText('.co-m-horizontal-nav__menu-item', name));
@@ -7,4 +5,4 @@ export const horizontalTabFor = (name: string) => element(by.cssContainingText('
 export const clickHorizontalTab = (tabName: string) => browser.wait(until.visibilityOf(horizontalTabFor(tabName)))
   .then(() => horizontalTabFor(tabName).click());
 
-export const activeTab = $$('co-m-horizontal-nav-item--active');
+export const activeTab = $$('.co-m-horizontal-nav-item--active');
