@@ -2,13 +2,13 @@ import { $, $$, browser, ExpectedConditions as until } from 'protractor';
 
 const BROWSER_TIMEOUT = 15000;
 
-const addMoreBtn = $('.pairs-list__add-btn');
-export const cancelBtn = $$('.btn-default').filter(link => link.getText().then(text => text.startsWith('Cancel'))).first();
+const addMoreBtn = $('[data-test-id="pairs-list__add-btn"]');
+export const cancelBtn = $$('.pf-m-secondary').filter(link => link.getText().then(text => text.startsWith('Cancel'))).first();
 export const confirmActionBtn = $('#confirm-action');
 const annotationRows = $$('.pairs-list__row');
 export const annotationRowsKey = $$('[placeholder="key"]');
 export const annotationRowsValue = $$('[placeholder="value"]');
-export const annotationRowsDelete = $$('.pairs-list__delete-icon');
+export const annotationRowsDelete = $$('[data-test-id="pairs-list__delete-btn"]');
 export const annotationDialogOverlay = $('.co-overlay');
 
 export const isLoaded = () => browser.wait(until.presenceOf(addMoreBtn), BROWSER_TIMEOUT);
