@@ -504,7 +504,7 @@ const APIResourceAccessReview: React.FC<APIResourceTabProps> = ({customData: {ki
           The following subjects can {verb} {plural}
           {namespaced && namespace && <> in namespace {namespace}</>}
           {namespaced && !namespace && <> in all namespaces</>}
-          {namespaced && <> at the cluster scope</>}
+          {!namespaced && <> at the cluster scope</>}
           .
         </p>
         <Table
