@@ -3,7 +3,8 @@ import * as PropTypes from 'prop-types';
 
 import { k8sKill } from '../../module/k8s';
 import { createModalLauncher, ModalTitle, ModalBody, ModalSubmitFooter } from '../factory/modal';
-import { history, PromiseComponent} from '../utils';
+import { history, PromiseComponent } from '../utils';
+import { YellowExclamationTriangleIcon } from '@console/shared';
 
 class DeleteNamespaceModal extends PromiseComponent {
   constructor(props) {
@@ -23,24 +24,24 @@ class DeleteNamespaceModal extends PromiseComponent {
     event.preventDefault();
     this.handlePromise(k8sKill(this.props.kind, this.props.resource)).then(() => {
       this._close();
-      history.push(`/k8s/cluster/${this.props.kind.path}`);
+      history.push(`/k8s/cluster/${this.props.kind.plural}`);
     });
   }
 
   render() {
     return <form onSubmit={this._submit} name="form" className="modal-content ">
       <ModalTitle>Delete {this.props.kind.label}</ModalTitle>
-      <ModalBody className="modal-body">
+      <ModalBody>
         <div className="co-delete-modal">
-          <span aria-hidden="true" className="co-delete-modal__icon pficon pficon-warning-triangle-o"></span>
+          <YellowExclamationTriangleIcon className="co-delete-modal__icon" />
           <div>
             <p>This action cannot be undone. It will destroy all pods, services and other objects in the deleted namespace.</p>
-            <p>Confirm deletion by typing <strong>{this.props.resource.metadata.name}</strong> below:</p>
-            <input type="text" className="form-control" onKeyUp={this._matchTypedNamespace} placeholder="Enter name" autoFocus={true} />
+            <p>Confirm deletion by typing <strong className="co-break-word">{this.props.resource.metadata.name}</strong> below:</p>
+            <input type="text" className="pf-c-form-control" onKeyUp={this._matchTypedNamespace} placeholder="Enter name" autoFocus={true} />
           </div>
         </div>
       </ModalBody>
-      <ModalSubmitFooter submitText="Delete" submitDisabled={!this.state.isTypedNsMatching} submitButtonClass="btn-danger" cancel={this._cancel} errorMessage={this.state.errorMessage} inProgress={this.state.inProgress} />
+      <ModalSubmitFooter submitText="Delete" submitDisabled={!this.state.isTypedNsMatching} cancel={this._cancel} errorMessage={this.state.errorMessage} inProgress={this.state.inProgress} submitDanger />
     </form>;
   }
 }
