@@ -1,6 +1,7 @@
 import * as React from 'react';
+import { CloseIcon } from '@patternfly/react-icons';
 
 export const CloseButton = ({onClick}) =>
   <button aria-label="Close" className="close" onClick={onClick} type="button">
-    <span aria-hidden="true" className="pficon pficon-close"></span>
+    <CloseIcon />
   </button>;
